==> ponyc-0.13.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/term-ANSI.md <==
# ANSI

These strings can be embedded in text when writing to a StdStream to create
a text-based UI.


```pony
primitive val ANSI
```

## Constructors

### create

```pony
new val create()
: ANSI val^
```

#### Returns

* [ANSI](term-ANSI) val^

---

## Public Functions

### up

Move the cursor up n lines. 0 is the same as 1.


```pony
fun box up(
  n: U32 val = 0)
: String val
```
#### Parameters

*   n: [U32](builtin-U32) val = 0

#### Returns

* [String](builtin-String) val

---

### down

Move the cursor down n lines. 0 is the same as 1.


```pony
fun box down(
  n: U32 val = 0)
: String val
```
#### Parameters

*   n: [U32](builtin-U32) val = 0

#### Returns

* [String](builtin-String) val

---

### right

Move the cursor right n columns. 0 is the same as 1.


```pony
fun box right(
  n: U32 val = 0)
: String val
```
#### Parameters

*   n: [U32](builtin-U32) val = 0

#### Returns

* [String](builtin-String) val

---

### left

Move the cursor left n columns. 0 is the same as 1.


```pony
fun box left(
  n: U32 val = 0)
: String val
```
#### Parameters

*   n: [U32](builtin-U32) val = 0

#### Returns

* [String](builtin-String) val

---

### cursor

Move the cursor to line y, column x. 0 is the same as 1. This indexes from
the top left corner of the screen.


```pony
fun box cursor(
  x: U32 val = 0,
  y: U32 val = 0)
: String val
```
#### Parameters

*   x: [U32](builtin-U32) val = 0
*   y: [U32](builtin-U32) val = 0

#### Returns

* [String](builtin-String) val

---

### clear

Clear the screen and move the cursor to the top left corner.


```pony
fun box clear()
: String val
```

#### Returns

* [String](builtin-String) val

---

### erase

Erases everything to the left of the cursor on the line the cursor is on.


```pony
fun box erase()
: String val
```

#### Returns

* [String](builtin-String) val

---

### reset

Resets all colours and text styles to the default.


```pony
fun box reset()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bold

Bold text. Does nothing on Windows.


```pony
fun box bold(
  state: Bool val = true)
: String val
```
#### Parameters

*   state: [Bool](builtin-Bool) val = true

#### Returns

* [String](builtin-String) val

---

### underline

Underlined text. Does nothing on Windows.


```pony
fun box underline(
  state: Bool val = true)
: String val
```
#### Parameters

*   state: [Bool](builtin-Bool) val = true

#### Returns

* [String](builtin-String) val

---

### blink

Blinking text. Does nothing on Windows.


```pony
fun box blink(
  state: Bool val = true)
: String val
```
#### Parameters

*   state: [Bool](builtin-Bool) val = true

#### Returns

* [String](builtin-String) val

---

### reverse

Swap foreground and background colour.


```pony
fun box reverse(
  state: Bool val = true)
: String val
```
#### Parameters

*   state: [Bool](builtin-Bool) val = true

#### Returns

* [String](builtin-String) val

---

### black

Black text.


```pony
fun box black()
: String val
```

#### Returns

* [String](builtin-String) val

---

### red

Red text.


```pony
fun box red()
: String val
```

#### Returns

* [String](builtin-String) val

---

### green

Green text.


```pony
fun box green()
: String val
```

#### Returns

* [String](builtin-String) val

---

### yellow

Yellow text.


```pony
fun box yellow()
: String val
```

#### Returns

* [String](builtin-String) val

---

### blue

Blue text.


```pony
fun box blue()
: String val
```

#### Returns

* [String](builtin-String) val

---

### magenta

Magenta text.


```pony
fun box magenta()
: String val
```

#### Returns

* [String](builtin-String) val

---

### cyan

Cyan text.


```pony
fun box cyan()
: String val
```

#### Returns

* [String](builtin-String) val

---

### grey

Grey text.


```pony
fun box grey()
: String val
```

#### Returns

* [String](builtin-String) val

---

### white

White text.


```pony
fun box white()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_red

Bright red text.


```pony
fun box bright_red()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_green

Bright green text.


```pony
fun box bright_green()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_yellow

Bright yellow text.


```pony
fun box bright_yellow()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_blue

Bright blue text.


```pony
fun box bright_blue()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_magenta

Bright magenta text.


```pony
fun box bright_magenta()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_cyan

Bright cyan text.


```pony
fun box bright_cyan()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_grey

Bright grey text.


```pony
fun box bright_grey()
: String val
```

#### Returns

* [String](builtin-String) val

---

### black_bg

Black background.


```pony
fun box black_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### red_bg

Red background.


```pony
fun box red_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### green_bg

Green background.


```pony
fun box green_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### yellow_bg

Yellow background.


```pony
fun box yellow_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### blue_bg

Blue background.


```pony
fun box blue_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### magenta_bg

Magenta background.


```pony
fun box magenta_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### cyan_bg

Cyan background.


```pony
fun box cyan_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### grey_bg

Grey background.


```pony
fun box grey_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### white_bg

White background.


```pony
fun box white_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_red_bg

Bright red background.


```pony
fun box bright_red_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_green_bg

Bright green background.


```pony
fun box bright_green_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_yellow_bg

Bright yellow background.


```pony
fun box bright_yellow_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_blue_bg

Bright blue background.


```pony
fun box bright_blue_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_magenta_bg

Bright magenta background.


```pony
fun box bright_magenta_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_cyan_bg

Bright cyan background.


```pony
fun box bright_cyan_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_grey_bg

Bright grey background.


```pony
fun box bright_grey_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### eq

```pony
fun box eq(
  that: ANSI val)
: Bool val
```
#### Parameters

*   that: [ANSI](term-ANSI) val

#### Returns

* [Bool](builtin-Bool) val

---

### ne

```pony
fun box ne(
  that: ANSI val)
: Bool val
```
#### Parameters

*   that: [ANSI](term-ANSI) val

#### Returns

* [Bool](builtin-Bool) val

---

==> ponyc-0.21.2-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/term-ANSI.md <==
# ANSI

These strings can be embedded in text when writing to a StdStream to create
a text-based UI.


```pony
primitive val ANSI
```

## Constructors

### create

```pony
new val create()
: ANSI val^
```

#### Returns

* [ANSI](term-ANSI) val^

---

## Public Functions

### up

Move the cursor up n lines. 0 is the same as 1.


```pony
fun box up(
  n: U32 val = seq)
: String val
```
#### Parameters

*   n: [U32](builtin-U32) val = seq

#### Returns

* [String](builtin-String) val

---

### down

Move the cursor down n lines. 0 is the same as 1.


```pony
fun box down(
  n: U32 val = seq)
: String val
```
#### Parameters

*   n: [U32](builtin-U32) val = seq

#### Returns

* [String](builtin-String) val

---

### right

Move the cursor right n columns. 0 is the same as 1.


```pony
fun box right(
  n: U32 val = seq)
: String val
```
#### Parameters

*   n: [U32](builtin-U32) val = seq

#### Returns

* [String](builtin-String) val

---

### left

Move the cursor left n columns. 0 is the same as 1.


```pony
fun box left(
  n: U32 val = seq)
: String val
```
#### Parameters

*   n: [U32](builtin-U32) val = seq

#### Returns

* [String](builtin-String) val

---

### cursor

Move the cursor to line y, column x. 0 is the same as 1. This indexes from
the top left corner of the screen.


```pony
fun box cursor(
  x: U32 val = seq,
  y: U32 val = seq)
: String val
```
#### Parameters

*   x: [U32](builtin-U32) val = seq
*   y: [U32](builtin-U32) val = seq

#### Returns

* [String](builtin-String) val

---

### clear

Clear the screen and move the cursor to the top left corner.


```pony
fun box clear()
: String val
```

#### Returns

* [String](builtin-String) val

---

### erase

Erases everything to the left of the cursor on the line the cursor is on.


```pony
fun box erase()
: String val
```

#### Returns

* [String](builtin-String) val

---

### reset

Resets all colours and text styles to the default.


```pony
fun box reset()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bold

Bold text. Does nothing on Windows.


```pony
fun box bold(
  state: Bool val = seq)
: String val
```
#### Parameters

*   state: [Bool](builtin-Bool) val = seq

#### Returns

* [String](builtin-String) val

---

### underline

Underlined text. Does nothing on Windows.


```pony
fun box underline(
  state: Bool val = seq)
: String val
```
#### Parameters

*   state: [Bool](builtin-Bool) val = seq

#### Returns

* [String](builtin-String) val

---

### blink

Blinking text. Does nothing on Windows.


```pony
fun box blink(
  state: Bool val = seq)
: String val
```
#### Parameters

*   state: [Bool](builtin-Bool) val = seq

#### Returns

* [String](builtin-String) val

---

### reverse

Swap foreground and background colour.


```pony
fun box reverse(
  state: Bool val = seq)
: String val
```
#### Parameters

*   state: [Bool](builtin-Bool) val = seq

#### Returns

* [String](builtin-String) val

---

### black

Black text.


```pony
fun box black()
: String val
```

#### Returns

* [String](builtin-String) val

---

### red

Red text.


```pony
fun box red()
: String val
```

#### Returns

* [String](builtin-String) val

---

### green

Green text.


```pony
fun box green()
: String val
```

#### Returns

* [String](builtin-String) val

---

### yellow

Yellow text.


```pony
fun box yellow()
: String val
```

#### Returns

* [String](builtin-String) val

---

### blue

Blue text.


```pony
fun box blue()
: String val
```

#### Returns

* [String](builtin-String) val

---

### magenta

Magenta text.


```pony
fun box magenta()
: String val
```

#### Returns

* [String](builtin-String) val

---

### cyan

Cyan text.


```pony
fun box cyan()
: String val
```

#### Returns

* [String](builtin-String) val

---

### grey

Grey text.


```pony
fun box grey()
: String val
```

#### Returns

* [String](builtin-String) val

---

### white

White text.


```pony
fun box white()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_red

Bright red text.


```pony
fun box bright_red()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_green

Bright green text.


```pony
fun box bright_green()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_yellow

Bright yellow text.


```pony
fun box bright_yellow()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_blue

Bright blue text.


```pony
fun box bright_blue()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_magenta

Bright magenta text.


```pony
fun box bright_magenta()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_cyan

Bright cyan text.


```pony
fun box bright_cyan()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_grey

Bright grey text.


```pony
fun box bright_grey()
: String val
```

#### Returns

* [String](builtin-String) val

---

### black_bg

Black background.


```pony
fun box black_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### red_bg

Red background.


```pony
fun box red_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### green_bg

Green background.


```pony
fun box green_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### yellow_bg

Yellow background.


```pony
fun box yellow_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### blue_bg

Blue background.


```pony
fun box blue_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### magenta_bg

Magenta background.


```pony
fun box magenta_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### cyan_bg

Cyan background.


```pony
fun box cyan_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### grey_bg

Grey background.


```pony
fun box grey_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### white_bg

White background.


```pony
fun box white_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_red_bg

Bright red background.


```pony
fun box bright_red_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_green_bg

Bright green background.


```pony
fun box bright_green_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_yellow_bg

Bright yellow background.


```pony
fun box bright_yellow_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_blue_bg

Bright blue background.


```pony
fun box bright_blue_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_magenta_bg

Bright magenta background.


```pony
fun box bright_magenta_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_cyan_bg

Bright cyan background.


```pony
fun box bright_cyan_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### bright_grey_bg

Bright grey background.


```pony
fun box bright_grey_bg()
: String val
```

#### Returns

* [String](builtin-String) val

---

### eq

```pony
fun box eq(
  that: ANSI val)
: Bool val
```
#### Parameters

*   that: [ANSI](term-ANSI) val

#### Returns

* [Bool](builtin-Bool) val

---

### ne

```pony
fun box ne(
  that: ANSI val)
: Bool val
```
#### Parameters

*   that: [ANSI](term-ANSI) val

#### Returns

* [Bool](builtin-Bool) val

---
